/**************************************************************************//**
*   @file   ad7400a.h  
*   @brief  Header file for the ad7400a ADC altera avalon IP
*   @author ACostina
*   
*******************************************************************************
* Copyright 2011(c) Analog Devices, Inc.
*
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without modification, 
* are permitted provided that the following conditions are met:
*  - Redistributions of source code must retain the above copyright
*    notice, this list of conditions and the following disclaimer.
*  - Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in
*    the documentation and/or other materials provided with the
*    distribution.
*  - Neither the name of Analog Devices, Inc. nor the names of its
*    contributors may be used to endorse or promote products derived
*    from this software without specific prior written permission.
*  - The use of this software may or may not infringe the patent rights
*    of one or more patent holders.  This license does not release you
*    from the requirement that you obtain separate licenses from these
*    patent holders to use this software.
*  - Use of the software either in source or binary form, must be run
*    on or directly connected to an Analog Devices Inc. component.
*
* THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR IMPLIED 
* WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT, MERCHANTABILITY 
* AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
* SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
* INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
* LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND 
* ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*
*******************************************************************************
*   SVN Revision: 1581
******************************************************************************/
#ifndef __ad7400a_H__
#define __ad7400a_H__

/*****************************************************************************/
/***************************** Include Files *********************************/
/*****************************************************************************/

#include "alt_types.h"

/*****************************************************************************/
/******************* Macros and Constants Definitions ************************/
/*****************************************************************************/

#define MEMORY_LINE_SIZE    512
#define MAX_MEMORY_LINES    1024
#define MEMORY_SIZE         (MEMORY_LINE_SIZE * MAX_MEMORY_LINES)
#define POWERDOWN			0
#define RANGE_5V			0
#define	RANGE_10V			1
#define NO_STAND_BY			(1 << 1)
#define	NO_OS				(0 << 2)
#define	OS2					(1 << 2)
#define	OS4					(2 << 2)
#define	OS8					(3 << 2)
#define	OS16				(4 << 2)
#define	OS32				(5 << 2)
#define	OS64				(6 << 2)
#define CHAN1				(0 << 5)
#define CHAN2				(1 << 5)
#define CHAN3				(2 << 5)
#define CHAN4				(3 << 5)
#define CHAN5				(4 << 5)
#define CHAN6				(5 << 5)
#define CHAN7				(6 << 5)
#define CHAN8				(7 << 5)

/*****************************************************************************/
/************************ Functions Declarations *****************************/
/*****************************************************************************/

void AD7400A_Reset(void);
int  AD7400A_StartAcquisition(int size, int destination);
int  AD7400A_ReadStatus(void);
void AD7400A_WriteRegister (int);

#endif /*__ad7400a_H__ */
